@@ -5,7 +5,6 @@ use Pcore::Nginx;
 use Pcore::HTTP::Server;
 use Pcore::App::Router;
 use Pcore::App::API;
-use Pcore::RPC::Hub;
 
 has app_cfg => ( required => 1, isa => HashRef );
 has devel   => ( default  => 0, isa => Bool );
@@ -13,7 +12,7 @@ has devel   => ( default  => 0, isa => Bool );
 has server => ( isa => InstanceOf ['Pcore::HTTP::Server'], init_arg => undef );
 has router => ( isa => InstanceOf ['Pcore::App::Router'],  init_arg => undef );
 has api => ( isa => Maybe [ ConsumerOf ['Pcore::App::API'] ], init_arg => undef );
-has rpc => ( is => 'lazy', isa => InstanceOf ['Pcore::RPC::Hub'], init_arg => undef );
+has node => ();    # InstanceOf ['Pcore::Node']
 
 sub BUILD ( $self, $args ) {
 
@@ -32,10 +31,6 @@ sub BUILD ( $self, $args ) {
     return;
 }
 
-sub _build_rpc ($self) {
-    return $self->{rpc} = Pcore::RPC::Hub->new;
-}
-
 around run => sub ( $orig, $self ) {
     if ( $self->{api} ) {
 
