@@ -3,10 +3,9 @@ package Pcore::App::API::Map;
 use Pcore -class;
 use Pcore::Util::Scalar qw[is_plain_arrayref];
 
-has app => ( is => 'ro', isa => ConsumerOf ['Pcore::App'], required => 1 );
-
-has method => ( is => 'ro', isa => HashRef, init_arg => undef );
-has obj => ( is => 'ro', isa => HashRef, default => sub { {} }, init_arg => undef );
+has app    => ();    # ( isa => ConsumerOf ['Pcore::App'], required => 1 );
+has method => ();    # ( isa => HashRef, init_arg => undef );
+has obj    => ();    # ( isa => HashRef, init_arg => undef );
 
 # TODO https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md
 
@@ -73,7 +72,7 @@ sub init ($self) {
 
         P->class->load($class_name);
 
-        die qq["$class_name" must be a consumer of "Pcore::App::API::Role"] if !$class_name->does('Pcore::App::API::Role');
+        die qq["$class_name" must be an instance of "Pcore::App::API::Role"] if !$class_name->isa('Pcore::App::API::Role');
 
         # prepare API object route
         $class_path =~ s/\AV/v/sm;
@@ -155,7 +154,7 @@ sub get_method ( $self, $method_id ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 127, 133             | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
+## |    3 | 126, 132             | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
